AstroPixCandidateInput
======================

.. currentmodule:: toasty.pipeline.astropix

.. autoclass:: AstroPixCandidateInput
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~AstroPixCandidateInput.get_unique_id
      ~AstroPixCandidateInput.save

   .. rubric:: Methods Documentation

   .. automethod:: get_unique_id
   .. automethod:: save
